@@ -35,6 +35,7 @@
 #include "xml_stats.h"
 #include "json_stats.h"
 #include "svg_stats.h"
+#include "raw_stats.h"
 #endif
 
 /*
@@ -92,6 +93,7 @@ struct activity cpu_act = {
 	.f_xml_print	= xml_print_cpu_stats,
 	.f_json_print	= json_print_cpu_stats,
 	.f_svg_print	= svg_print_cpu_stats,
+	.f_raw_print	= raw_print_cpu_stats,
 	.name		= "A_CPU",
 	.g_nr		= 1,
 #endif
@@ -128,6 +130,7 @@ struct activity pcsw_act = {
 	.f_xml_print	= xml_print_pcsw_stats,
 	.f_json_print	= json_print_pcsw_stats,
 	.f_svg_print	= svg_print_pcsw_stats,
+	.f_raw_print	= raw_print_pcsw_stats,
 	.name		= "A_PCSW",
 	.g_nr		= 2,
 #endif
@@ -163,6 +166,8 @@ struct activity irq_act = {
 	.f_render	= render_irq_stats,
 	.f_xml_print	= xml_print_irq_stats,
 	.f_json_print	= json_print_irq_stats,
+	.f_svg_print	= NULL,
+	.f_raw_print	= raw_print_irq_stats,
 	.name		= "A_IRQ",
 	.g_nr		= 0,
 #endif
@@ -199,6 +204,7 @@ struct activity swap_act = {
 	.f_xml_print	= xml_print_swap_stats,
 	.f_json_print	= json_print_swap_stats,
 	.f_svg_print	= svg_print_swap_stats,
+	.f_raw_print	= raw_print_swap_stats,
 	.name		= "A_SWAP",
 	.g_nr		= 1,
 #endif
@@ -236,6 +242,7 @@ struct activity paging_act = {
 	.f_xml_print	= xml_print_paging_stats,
 	.f_json_print	= json_print_paging_stats,
 	.f_svg_print	= svg_print_paging_stats,
+	.f_raw_print	= raw_print_paging_stats,
 	.name		= "A_PAGE",
 	.g_nr		= 3,
 #endif
@@ -272,6 +279,7 @@ struct activity io_act = {
 	.f_xml_print	= xml_print_io_stats,
 	.f_json_print	= json_print_io_stats,
 	.f_svg_print	= svg_print_io_stats,
+	.f_raw_print	= raw_print_io_stats,
 	.name		= "A_IO",
 	.g_nr		= 2,
 #endif
@@ -301,8 +309,7 @@ struct activity memory_act = {
 	.f_print_avg	= print_avg_memory_stats,
 #endif
 #if defined(SOURCE_SAR) || defined(SOURCE_SADF)
-	.hdr_line	= "frmpg/s;bufpg/s;campg/s|"
-		          "kbmemfree;kbavail;kbmemused;%memused;kbbuffers;kbcached;kbcommit;%commit;kbactive;kbinact;kbdirty&kbanonpg;kbslab;kbkstack;kbpgtbl;kbvmused|"
+	.hdr_line	= "kbmemfree;kbavail;kbmemused;%memused;kbbuffers;kbcached;kbcommit;%commit;kbactive;kbinact;kbdirty&kbanonpg;kbslab;kbkstack;kbpgtbl;kbvmused|"
 		          "kbswpfree;kbswpused;%swpused;kbswpcad;%swpcad",
 #endif
 #ifdef SOURCE_SADF
@@ -310,6 +317,7 @@ struct activity memory_act = {
 	.f_xml_print	= xml_print_memory_stats,
 	.f_json_print	= json_print_memory_stats,
 	.f_svg_print	= svg_print_memory_stats,
+	.f_raw_print	= raw_print_memory_stats,
 	.name		= "A_MEMORY",
 	.g_nr		= 9,
 #endif
@@ -346,6 +354,7 @@ struct activity ktables_act = {
 	.f_xml_print	= xml_print_ktables_stats,
 	.f_json_print	= json_print_ktables_stats,
 	.f_svg_print	= svg_print_ktables_stats,
+	.f_raw_print	= raw_print_ktables_stats,
 	.name		= "A_KTABLES",
 	.g_nr		= 2,
 #endif
@@ -382,6 +391,7 @@ struct activity queue_act = {
 	.f_xml_print	= xml_print_queue_stats,
 	.f_json_print	= json_print_queue_stats,
 	.f_svg_print	= svg_print_queue_stats,
+	.f_raw_print	= raw_print_queue_stats,
 	.name		= "A_QUEUE",
 	.g_nr		= 3,
 #endif
@@ -417,6 +427,8 @@ struct activity serial_act = {
 	.f_render	= render_serial_stats,
 	.f_xml_print	= xml_print_serial_stats,
 	.f_json_print	= json_print_serial_stats,
+	.f_svg_print	= NULL,
+	.f_raw_print	= raw_print_serial_stats,
 	.name		= "A_SERIAL",
 	.g_nr		= 0,
 #endif
@@ -453,6 +465,7 @@ struct activity disk_act = {
 	.f_xml_print	= xml_print_disk_stats,
 	.f_json_print	= json_print_disk_stats,
 	.f_svg_print	= svg_print_disk_stats,
+	.f_raw_print	= raw_print_disk_stats,
 	.name		= "A_DISK",
 	.g_nr		= 5,
 #endif
@@ -489,6 +502,7 @@ struct activity net_dev_act = {
 	.f_xml_print	= xml_print_net_dev_stats,
 	.f_json_print	= json_print_net_dev_stats,
 	.f_svg_print	= svg_print_net_dev_stats,
+	.f_raw_print	= raw_print_net_dev_stats,
 	.name		= "A_NET_DEV",
 	.g_nr		= 4,
 #endif
@@ -526,6 +540,7 @@ struct activity net_edev_act = {
 	.f_xml_print	= xml_print_net_edev_stats,
 	.f_json_print	= json_print_net_edev_stats,
 	.f_svg_print	= svg_print_net_edev_stats,
+	.f_raw_print	= raw_print_net_edev_stats,
 	.name		= "A_NET_EDEV",
 	.g_nr		= 4,
 #endif
@@ -562,6 +577,7 @@ struct activity net_nfs_act = {
 	.f_xml_print	= xml_print_net_nfs_stats,
 	.f_json_print	= json_print_net_nfs_stats,
 	.f_svg_print	= svg_print_net_nfs_stats,
+	.f_raw_print	= raw_print_net_nfs_stats,
 	.name		= "A_NET_NFS",
 	.g_nr		= 3,
 #endif
@@ -599,6 +615,7 @@ struct activity net_nfsd_act = {
 	.f_xml_print	= xml_print_net_nfsd_stats,
 	.f_json_print	= json_print_net_nfsd_stats,
 	.f_svg_print	= svg_print_net_nfsd_stats,
+	.f_raw_print	= raw_print_net_nfsd_stats,
 	.name		= "A_NET_NFSD",
 	.g_nr		= 5,
 #endif
@@ -635,6 +652,7 @@ struct activity net_sock_act = {
 	.f_xml_print	= xml_print_net_sock_stats,
 	.f_json_print	= json_print_net_sock_stats,
 	.f_svg_print	= svg_print_net_sock_stats,
+	.f_raw_print	= raw_print_net_sock_stats,
 	.name		= "A_NET_SOCK",
 	.g_nr		= 2,
 #endif
@@ -671,6 +689,7 @@ struct activity net_ip_act = {
 	.f_xml_print	= xml_print_net_ip_stats,
 	.f_json_print	= json_print_net_ip_stats,
 	.f_svg_print	= svg_print_net_ip_stats,
+	.f_raw_print	= raw_print_net_ip_stats,
 	.name		= "A_NET_IP",
 	.g_nr		= 3,
 #endif
@@ -707,6 +726,7 @@ struct activity net_eip_act = {
 	.f_xml_print	= xml_print_net_eip_stats,
 	.f_json_print	= json_print_net_eip_stats,
 	.f_svg_print	= svg_print_net_eip_stats,
+	.f_raw_print	= raw_print_net_eip_stats,
 	.name		= "A_NET_EIP",
 	.g_nr		= 3,
 #endif
@@ -744,6 +764,7 @@ struct activity net_icmp_act = {
 	.f_xml_print	= xml_print_net_icmp_stats,
 	.f_json_print	= json_print_net_icmp_stats,
 	.f_svg_print	= svg_print_net_icmp_stats,
+	.f_raw_print	= raw_print_net_icmp_stats,
 	.name		= "A_NET_ICMP",
 	.g_nr		= 4,
 #endif
@@ -781,6 +802,7 @@ struct activity net_eicmp_act = {
 	.f_xml_print	= xml_print_net_eicmp_stats,
 	.f_json_print	= json_print_net_eicmp_stats,
 	.f_svg_print	= svg_print_net_eicmp_stats,
+	.f_raw_print	= raw_print_net_eicmp_stats,
 	.name		= "A_NET_EICMP",
 	.g_nr		= 6,
 #endif
@@ -817,6 +839,7 @@ struct activity net_tcp_act = {
 	.f_xml_print	= xml_print_net_tcp_stats,
 	.f_json_print	= json_print_net_tcp_stats,
 	.f_svg_print	= svg_print_net_tcp_stats,
+	.f_raw_print	= raw_print_net_tcp_stats,
 	.name		= "A_NET_TCP",
 	.g_nr		= 2,
 #endif
@@ -853,6 +876,7 @@ struct activity net_etcp_act = {
 	.f_xml_print	= xml_print_net_etcp_stats,
 	.f_json_print	= json_print_net_etcp_stats,
 	.f_svg_print	= svg_print_net_etcp_stats,
+	.f_raw_print	= raw_print_net_etcp_stats,
 	.name		= "A_NET_ETCP",
 	.g_nr		= 2,
 #endif
@@ -889,6 +913,7 @@ struct activity net_udp_act = {
 	.f_xml_print	= xml_print_net_udp_stats,
 	.f_json_print	= json_print_net_udp_stats,
 	.f_svg_print	= svg_print_net_udp_stats,
+	.f_raw_print	= raw_print_net_udp_stats,
 	.name		= "A_NET_UDP",
 	.g_nr		= 2,
 #endif
@@ -925,6 +950,7 @@ struct activity net_sock6_act = {
 	.f_xml_print	= xml_print_net_sock6_stats,
 	.f_json_print	= json_print_net_sock6_stats,
 	.f_svg_print	= svg_print_net_sock6_stats,
+	.f_raw_print	= raw_print_net_sock6_stats,
 	.name		= "A_NET_SOCK6",
 	.g_nr		= 1,
 #endif
@@ -962,6 +988,7 @@ struct activity net_ip6_act = {
 	.f_xml_print	= xml_print_net_ip6_stats,
 	.f_json_print	= json_print_net_ip6_stats,
 	.f_svg_print	= svg_print_net_ip6_stats,
+	.f_raw_print	= raw_print_net_ip6_stats,
 	.name		= "A_NET_IP6",
 	.g_nr		= 4,
 #endif
@@ -999,6 +1026,7 @@ struct activity net_eip6_act = {
 	.f_xml_print	= xml_print_net_eip6_stats,
 	.f_json_print	= json_print_net_eip6_stats,
 	.f_svg_print	= svg_print_net_eip6_stats,
+	.f_raw_print	= raw_print_net_eip6_stats,
 	.name		= "A_NET_EIP6",
 	.g_nr		= 4,
 #endif
@@ -1037,6 +1065,7 @@ struct activity net_icmp6_act = {
 	.f_xml_print	= xml_print_net_icmp6_stats,
 	.f_json_print	= json_print_net_icmp6_stats,
 	.f_svg_print	= svg_print_net_icmp6_stats,
+	.f_raw_print	= raw_print_net_icmp6_stats,
 	.name		= "A_NET_ICMP6",
 	.g_nr		= 5,
 #endif
@@ -1074,6 +1103,7 @@ struct activity net_eicmp6_act = {
 	.f_xml_print	= xml_print_net_eicmp6_stats,
 	.f_json_print	= json_print_net_eicmp6_stats,
 	.f_svg_print	= svg_print_net_eicmp6_stats,
+	.f_raw_print	= raw_print_net_eicmp6_stats,
 	.name		= "A_NET_EICMP6",
 	.g_nr		= 6,
 #endif
@@ -1110,6 +1140,7 @@ struct activity net_udp6_act = {
 	.f_xml_print	= xml_print_net_udp6_stats,
 	.f_json_print	= json_print_net_udp6_stats,
 	.f_svg_print	= svg_print_net_udp6_stats,
+	.f_raw_print	= raw_print_net_udp6_stats,
 	.name		= "A_NET_UDP6",
 	.g_nr		= 2,
 #endif
@@ -1146,6 +1177,7 @@ struct activity pwr_cpufreq_act = {
 	.f_xml_print	= xml_print_pwr_cpufreq_stats,
 	.f_json_print	= json_print_pwr_cpufreq_stats,
 	.f_svg_print	= svg_print_pwr_cpufreq_stats,
+	.f_raw_print	= raw_print_pwr_cpufreq_stats,
 	.name		= "A_PWR_CPUFREQ",
 	.g_nr		= 1,
 #endif
@@ -1182,6 +1214,7 @@ struct activity pwr_fan_act = {
 	.f_xml_print	= xml_print_pwr_fan_stats,
 	.f_json_print	= json_print_pwr_fan_stats,
 	.f_svg_print	= svg_print_pwr_fan_stats,
+	.f_raw_print	= raw_print_pwr_fan_stats,
 	.name		= "A_PWR_FAN",
 	.g_nr		= 1,
 #endif
@@ -1218,6 +1251,7 @@ struct activity pwr_temp_act = {
 	.f_xml_print	= xml_print_pwr_temp_stats,
 	.f_json_print	= json_print_pwr_temp_stats,
 	.f_svg_print	= svg_print_pwr_temp_stats,
+	.f_raw_print	= raw_print_pwr_temp_stats,
 	.name		= "A_PWR_TEMP",
 	.g_nr		= 2,
 #endif
@@ -1254,6 +1288,7 @@ struct activity pwr_in_act = {
 	.f_xml_print	= xml_print_pwr_in_stats,
 	.f_json_print	= json_print_pwr_in_stats,
 	.f_svg_print	= svg_print_pwr_in_stats,
+	.f_raw_print	= raw_print_pwr_in_stats,
 	.name		= "A_PWR_IN",
 	.g_nr		= 2,
 #endif
@@ -1290,6 +1325,7 @@ struct activity huge_act = {
 	.f_xml_print	= xml_print_huge_stats,
 	.f_json_print	= json_print_huge_stats,
 	.f_svg_print	= svg_print_huge_stats,
+	.f_raw_print	= raw_print_huge_stats,
 	.name		= "A_HUGE",
 	.g_nr		= 2,
 #endif
@@ -1325,6 +1361,8 @@ struct activity pwr_wghfreq_act = {
 	.f_render	= render_pwr_wghfreq_stats,
 	.f_xml_print	= xml_print_pwr_wghfreq_stats,
 	.f_json_print	= json_print_pwr_wghfreq_stats,
+	.f_svg_print	= NULL,
+	.f_raw_print	= raw_print_pwr_wghfreq_stats,
 	.name		= "A_PWR_WGHFREQ",
 	.g_nr		= 0,
 #endif
@@ -1360,6 +1398,8 @@ struct activity pwr_usb_act = {
 	.f_render	= render_pwr_usb_stats,
 	.f_xml_print	= xml_print_pwr_usb_stats,
 	.f_json_print	= json_print_pwr_usb_stats,
+	.f_svg_print	= NULL,
+	.f_raw_print	= raw_print_pwr_usb_stats,
 	.name		= "A_PWR_USB",
 	.g_nr		= 0,
 #endif
@@ -1397,6 +1437,7 @@ struct activity filesystem_act = {
 	.f_xml_print	= xml_print_filesystem_stats,
 	.f_json_print	= json_print_filesystem_stats,
 	.f_svg_print	= svg_print_filesystem_stats,
+	.f_raw_print	= raw_print_filesystem_stats,
 	.name		= "A_FILESYSTEM",
 	.g_nr		= 4,
 #endif
@@ -1433,6 +1474,7 @@ struct activity fchost_act = {
 	.f_xml_print	= xml_print_fchost_stats,
 	.f_json_print	= json_print_fchost_stats,
 	.f_svg_print	= svg_print_fchost_stats,
+	.f_raw_print	= raw_print_fchost_stats,
 	.name		= "A_FCHOST",
 	.g_nr		= 2,
 #endif
@@ -1469,6 +1511,7 @@ struct activity softnet_act = {
 	.f_xml_print	= xml_print_softnet_stats,
 	.f_json_print	= json_print_softnet_stats,
 	.f_svg_print	= svg_print_softnet_stats,
+	.f_raw_print	= raw_print_softnet_stats,
 	.name		= "A_NET_SOFT",
 	.g_nr		= 2,
 #endif
