@@ -34,8 +34,8 @@
 #include "rd_stats.h"
 #include "count.h"
 
+#include <locale.h>	/* For setlocale() */
 #ifdef USE_NLS
-#include <locale.h>
 #include <libintl.h>
 #define _(string) gettext(string)
 #else
@@ -100,7 +100,7 @@ void usage(char *progname)
 
 	fprintf(stderr, _("Options are:\n"
 			  "[ -A ] [ -u ] [ -V ] [ -I { SUM | CPU | SCPU | ALL } ]\n"
-			  "[ -o JSON ] [ -P { <cpu> [,...] | ON | ALL } ]\n"));
+			  "[ -o JSON ] [ -P { <cpu_list> | ON | ALL } ]\n"));
 	exit(1);
 }
 
@@ -604,7 +604,7 @@ void write_plain_isumcpu_stats(int dis, unsigned long long itv, int prev, int cu
 		printf("%-11s", curr_string);
 		cprintf_in(IS_STR, " %s", " all", 0);
 		/* Print total number of interrupts among all cpu */
-		cprintf_f(1, 9, 2,
+		cprintf_f(-1, 1, 9, 2,
 			  S_VALUE(st_irq[prev]->irq_nr, st_irq[curr]->irq_nr, itv));
 		printf("\n");
 	}
@@ -634,7 +634,7 @@ void write_plain_isumcpu_stats(int dis, unsigned long long itv, int prev, int cu
 				 */
 				printf("%-11s", curr_string);
 				cprintf_in(IS_INT, " %4d", "", cpu - 1);
-				cprintf_f(1, 9, 2, 0.0);
+				cprintf_f(-1, 1, 9, 2, 0.0);
 				printf("\n");
 			}
 			continue;
@@ -648,12 +648,12 @@ void write_plain_isumcpu_stats(int dis, unsigned long long itv, int prev, int cu
 
 		if (!pc_itv) {
 			/* This is a tickless CPU: Value displayed is 0.00 */
-			cprintf_f(1, 9, 2, 0.0);
+			cprintf_f(-1, 1, 9, 2, 0.0);
 			printf("\n");
 		}
 		else {
 			/* Display total number of interrupts for current CPU */
-			cprintf_f(1, 9, 2,
+			cprintf_f(-1, 1, 9, 2,
 				  S_VALUE(sip->irq_nr, sic->irq_nr, itv));
 			printf("\n");
 		}
@@ -921,7 +921,7 @@ void write_plain_irqcpu_stats(struct stats_irqcpu *st_ic[], int ic_nr, int dis,
 
 			if (!strcmp(p0->irq_name, q0->irq_name) || !interval) {
 				q = st_ic[prev] + (cpu - 1) * ic_nr + offset;
-				cprintf_f(1, colwidth[j], 2,
+				cprintf_f(-1, 1, colwidth[j], 2,
 					  S_VALUE(q->interrupt, p->interrupt, itv));
 			}
 			else {
@@ -929,7 +929,7 @@ void write_plain_irqcpu_stats(struct stats_irqcpu *st_ic[], int ic_nr, int dis,
 				 * Instead of printing "N/A", assume that previous value
 				 * for this new interrupt was zero.
 				 */
-				cprintf_f(1, colwidth[j], 2,
+				cprintf_f(-1, 1, colwidth[j], 2,
 					  S_VALUE(0, p->interrupt, itv));
 			}
 		}
@@ -1610,35 +1610,15 @@ int main(int argc, char **argv)
 			/* '-P ALL' can be used on UP machines */
 			if (argv[++opt]) {
 				flags |= F_P_OPTION;
-				dis_hdr++;
+				dis_hdr = 9;
 
-				for (t = strtok(argv[opt], ","); t; t = strtok(NULL, ",")) {
-					if (!strcmp(t, K_ALL) || !strcmp(t, K_ON)) {
-						if (cpu_nr) {
-							dis_hdr = 9;
-						}
-						/*
-						 * Set bit for every processor.
-						 * Also indicate to display stats for CPU 'all'.
-						 */
-						memset(cpu_bitmap, 0xff, ((cpu_nr + 1) >> 3) + 1);
-						if (!strcmp(t, K_ON)) {
-							/* Display stats only for online CPU */
-							flags |= F_P_ON;
-						}
-					}
-					else {
-						if (strspn(t, DIGITS) != strlen(t)) {
-							usage(argv[0]);
-						}
-						i = atoi(t);	/* Get cpu number */
-						if (i >= cpu_nr) {
-							fprintf(stderr, _("Not that many processors!\n"));
-							exit(1);
-						}
-						i++;
-						*(cpu_bitmap + (i >> 3)) |= 1 << (i & 0x07);
-					}
+				if (!strcmp(argv[opt], K_ON)) {
+					/* Display stats for all online CPU */
+					flags |= F_P_ON;
+					memset(cpu_bitmap, ~0, BITMAP_SIZE(cpu_nr));
+				}
+				else if (parse_values(argv[opt], cpu_bitmap, cpu_nr, K_LOWERALL)) {
+					usage(argv[0]);
 				}
 			}
 			else {
