@@ -475,8 +475,7 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 			     unsigned long long itv, int dispavg)
 {
 	struct stats_memory
-		*smc = (struct stats_memory *) a->buf[curr],
-		*smp = (struct stats_memory *) a->buf[prev];
+		*smc = (struct stats_memory *) a->buf[curr];
 	static unsigned long long
 		avg_frmkb       = 0,
 		avg_bufkb       = 0,
@@ -507,19 +506,6 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 			print_hdr_line(timestamp[!curr], a, FIRST, 0, 9);
 		}
 
-		printf("%-11s", timestamp[curr]);
-		cprintf_f(-1, 3, 9, 2,
-			  S_VALUE((double) KB_TO_PG(smp->frmkb), (double) KB_TO_PG(smc->frmkb), itv),
-			  S_VALUE((double) KB_TO_PG(smp->bufkb), (double) KB_TO_PG(smc->bufkb), itv),
-			  S_VALUE((double) KB_TO_PG(smp->camkb), (double) KB_TO_PG(smc->camkb), itv));
-		printf("\n");
-	}
-
-	if (DISPLAY_MEM_AMT(a->opt_flags)) {
-		if (dis) {
-			print_hdr_line(timestamp[!curr], a, SECOND, 0, 9);
-		}
-
 		if (!dispavg) {
 			/* Display instantaneous values */
 			printf("%-11s", timestamp[curr]);
@@ -620,7 +606,7 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 
 	if (DISPLAY_SWAP(a->opt_flags)) {
 		if (dis) {
-			print_hdr_line(timestamp[!curr], a, THIRD, 0, 9);
+			print_hdr_line(timestamp[!curr], a, SECOND, 0, 9);
 		}
 
 		if (!dispavg) {
@@ -975,11 +961,13 @@ __print_funct_t print_disk_stats(struct activity *a, int prev, int curr,
 				 unsigned long long itv)
 {
 	int i, j;
-	struct stats_disk *sdc,	*sdp;
+	struct stats_disk *sdc,	*sdp, sdpzero;
 	struct ext_disk_stats xds;
 	char *dev_name, *persist_dev_name;
 	int unit = -1;
 
+	memset(&sdpzero, 0, STATS_DISK_SIZE);
+
 	if (DISPLAY_UNIT(flags)) {
 		/* Default values unit is sectors */
 		unit = 0;
@@ -997,7 +985,13 @@ __print_funct_t print_disk_stats(struct activity *a, int prev, int curr,
 			continue;
 
 		j = check_disk_reg(a, curr, prev, i);
-		sdp = (struct stats_disk *) ((char *) a->buf[prev] + j * a->msize);
+		if (j < 0) {
+			/* This is a newly registered interface. Previous stats are zero */
+			sdp = &sdpzero;
+		}
+		else {
+			sdp = (struct stats_disk *) ((char *) a->buf[prev] + j * a->msize);
+		}
 
 		/* Compute service time, etc. */
 		compute_ext_disk_stats(sdc, sdp, itv, &xds);
@@ -1058,10 +1052,12 @@ __print_funct_t print_net_dev_stats(struct activity *a, int prev, int curr,
 				    unsigned long long itv)
 {
 	int i, j;
-	struct stats_net_dev *sndc, *sndp;
+	struct stats_net_dev *sndc, *sndp, sndzero;
 	double rxkb, txkb, ifutil;
 	int unit = -1;
 
+	memset(&sndzero, 0, STATS_NET_DEV_SIZE);
+
 	if (DISPLAY_UNIT(flags)) {
 		/* Default values unit is bytes */
 		unit = 1;
@@ -1076,10 +1072,16 @@ __print_funct_t print_net_dev_stats(struct activity *a, int prev, int curr,
 		sndc = (struct stats_net_dev *) ((char *) a->buf[curr] + i * a->msize);
 
 		if (!strcmp(sndc->interface, ""))
-			continue;
+			break;
 
 		j = check_net_dev_reg(a, curr, prev, i);
-		sndp = (struct stats_net_dev *) ((char *) a->buf[prev] + j * a->msize);
+		if (j < 0) {
+			/* This is a newly registered interface. Previous stats are zero */
+			sndp = &sndzero;
+		}
+		else {
+			sndp = (struct stats_net_dev *) ((char *) a->buf[prev] + j * a->msize);
+		}
 
 		printf("%-11s", timestamp[curr]);
 		cprintf_in(IS_STR, " %9s", sndc->interface, 0);
@@ -1088,8 +1090,8 @@ __print_funct_t print_net_dev_stats(struct activity *a, int prev, int curr,
 		txkb = S_VALUE(sndp->tx_bytes, sndc->tx_bytes, itv);
 
 		cprintf_f(-1, 2, 9, 2,
-			  S_VALUE(sndp->rx_packets,    sndc->rx_packets,    itv),
-			  S_VALUE(sndp->tx_packets,    sndc->tx_packets,    itv));
+			  S_VALUE(sndp->rx_packets, sndc->rx_packets, itv),
+			  S_VALUE(sndp->tx_packets, sndc->tx_packets, itv));
 		cprintf_f(unit, 2, 9, 2,
 			  unit < 0 ? rxkb / 1024 : rxkb,
 			  unit < 0 ? txkb / 1024 : txkb);
@@ -1118,7 +1120,9 @@ __print_funct_t print_net_edev_stats(struct activity *a, int prev, int curr,
 				     unsigned long long itv)
 {
 	int i, j;
-	struct stats_net_edev *snedc, *snedp;
+	struct stats_net_edev *snedc, *snedp, snedzero;
+
+	memset(&snedzero, 0, STATS_NET_EDEV_SIZE);
 
 	if (dis) {
 		print_hdr_line(timestamp[!curr], a, FIRST, 0, 9);
@@ -1129,10 +1133,16 @@ __print_funct_t print_net_edev_stats(struct activity *a, int prev, int curr,
 		snedc = (struct stats_net_edev *) ((char *) a->buf[curr] + i * a->msize);
 
 		if (!strcmp(snedc->interface, ""))
-			continue;
+			break;
 
 		j = check_net_edev_reg(a, curr, prev, i);
-		snedp = (struct stats_net_edev *) ((char *) a->buf[prev] + j * a->msize);
+		if (j < 0) {
+			/* This is a newly registered interface. Previous stats are zero */
+			snedp = &snedzero;
+		}
+		else {
+			snedp = (struct stats_net_edev *) ((char *) a->buf[prev] + j * a->msize);
+		}
 
 		printf("%-11s", timestamp[curr]);
 		cprintf_in(IS_STR, " %9s", snedc->interface, 0);
