@@ -99,6 +99,8 @@
 #define S_F_LOCAL_TIME		0x00004000
 #define S_F_PREFD_TIME_OUTPUT	0x00008000
 #define S_F_SVG_SKIP		0x00010000
+/* Same value as S_F_SVG_SKIP above. Used for a different output format */
+#define S_F_RAW_SHOW_HINTS	0x00010000
 #define S_F_SVG_AUTOSCALE	0x00020000
 #define S_F_SVG_ONE_DAY		0x00040000
 #define S_F_SVG_SHOW_IDLE	0x00080000
@@ -121,6 +123,7 @@
 #define PRINT_LOCAL_TIME(m)		(((m) & S_F_LOCAL_TIME)   == S_F_LOCAL_TIME)
 #define USE_PREFD_TIME_OUTPUT(m)	(((m) & S_F_PREFD_TIME_OUTPUT)   == S_F_PREFD_TIME_OUTPUT)
 #define SKIP_EMPTY_VIEWS(m)		(((m) & S_F_SVG_SKIP)     == S_F_SVG_SKIP)
+#define DISPLAY_HINTS(m)		(((m) & S_F_RAW_SHOW_HINTS) == S_F_RAW_SHOW_HINTS)
 #define AUTOSCALE_ON(m)			(((m) & S_F_SVG_AUTOSCALE) == S_F_SVG_AUTOSCALE)
 #define DISPLAY_ONE_DAY(m)		(((m) & S_F_SVG_ONE_DAY)   == S_F_SVG_ONE_DAY)
 #define DISPLAY_IDLE(m)			(((m) & S_F_SVG_SHOW_IDLE) == S_F_SVG_SHOW_IDLE)
@@ -128,17 +131,15 @@
 
 #define AO_F_NULL		0x00000000
 
-/* Output flags for options -R / -r / -S */
-#define AO_F_MEM_DIA		0x00000001
-#define AO_F_MEM_AMT		0x00000002
-#define AO_F_MEM_SWAP		0x00000004
+/* Output flags for options -r / -S */
+#define AO_F_MEMORY		0x00000001
+#define AO_F_SWAP		0x00000002
 /* AO_F_MEM_ALL: See opt_flags in struct activity below */
-#define AO_F_MEM_ALL		(AO_F_MEM_AMT << 8)
+#define AO_F_MEM_ALL		(AO_F_MEMORY << 8)
 
-#define DISPLAY_MEMORY(m)	(((m) & AO_F_MEM_DIA)     == AO_F_MEM_DIA)
-#define DISPLAY_MEM_AMT(m)	(((m) & AO_F_MEM_AMT)     == AO_F_MEM_AMT)
-#define DISPLAY_SWAP(m)		(((m) & AO_F_MEM_SWAP)    == AO_F_MEM_SWAP)
-#define DISPLAY_MEM_ALL(m)	(((m) & AO_F_MEM_ALL)     == AO_F_MEM_ALL)
+#define DISPLAY_MEMORY(m)	(((m) & AO_F_MEMORY)	== AO_F_MEMORY)
+#define DISPLAY_SWAP(m)		(((m) & AO_F_SWAP)	== AO_F_SWAP)
+#define DISPLAY_MEM_ALL(m)	(((m) & AO_F_MEM_ALL)	== AO_F_MEM_ALL)
 
 /* Output flags for option -u [ ALL ] */
 #define AO_F_CPU_DEF		0x00000001
@@ -206,6 +207,7 @@
 #define K_AUTOSCALE	"autoscale"
 #define K_ONEDAY	"oneday"
 #define K_SHOWIDLE	"showidle"
+#define K_SHOWHINTS	"showhints"
 
 /* Groups of activities */
 #define G_DEFAULT	0x00
@@ -268,7 +270,6 @@
 
 #define FIRST	0
 #define SECOND	1
-#define THIRD	2
 
 #define CLOSE_XML_MARKUP	0
 #define OPEN_XML_MARKUP		1
@@ -691,6 +692,10 @@ struct activity {
 	 */
 	__print_funct_t (*f_svg_print) (struct activity *, int, int, struct svg_parm *,
 					unsigned long long, struct record_header *);
+	/*
+	 * This function is used by sadf to display activity statistics in raw format.
+	 */
+	__print_funct_t (*f_raw_print) (struct activity *, char *, int);
 	/*
 	 * Header string displayed by sadf -d.
 	 * Header lines for each output (for activities with multiple outputs) are
@@ -758,7 +763,7 @@ struct activity {
 	/*
 	 * Optional flags for activity. This is eg. used when AO_MULTIPLE_OUTPUTS
 	 * option is set.
-	 * 0x0001 - 0x0080 : Multiple outputs (eg. AO_F_MEM_AMT, AO_F_MEM_SWAP...)
+	 * 0x0001 - 0x0080 : Multiple outputs (eg. AO_F_MEMORY, AO_F_SWAP...)
 	 * 0x0100 - 0x8000 : If bit set then display complete header (hdr_line) for
 	 *                   corresponding output
 	 * 0x010000+       : Optional flags
@@ -1083,10 +1088,10 @@ int check_disk_reg
 void check_file_actlst
 	(int *, char *, struct activity * [], struct file_magic *, struct file_header *,
 	 struct file_activity **, unsigned int [], int);
-unsigned int check_net_dev_reg
-	(struct activity *, int, int, unsigned int);
-unsigned int check_net_edev_reg
-	(struct activity *, int, int, unsigned int);
+int check_net_dev_reg
+	(struct activity *, int, int, int);
+int check_net_edev_reg
+	(struct activity *, int, int, int);
 double compute_ifutil
 	(struct stats_net_dev *, double, double);
 void copy_structures
