@@ -87,7 +87,7 @@ void usage(char *progname)
 		progname);
 
 	fprintf(stderr, _("Options are:\n"
-			  "[ -C ] [ -c | -d | -g | -j | -p | -x ] [ -H ] [ -h ] [ -T | -t | -U ] [ -V ]\n"
+			  "[ -C ] [ -c | -d | -g | -j | -p | -r | -x ] [ -H ] [ -h ] [ -T | -t | -U ] [ -V ]\n"
 			  "[ -O <opts> [,...] ] [ -P { <cpu> [,...] | ALL } ]\n"
 			  "[ -s [ <hh:mm[:ss]> ] ] [ -e [ <hh:mm[:ss]> ] ]\n"
 			  "[ -- <sar_options> ]\n"));
@@ -691,6 +691,11 @@ int generic_write_stats(int curr, int use_tm_start, int use_tm_end, int reset,
 						       &record_hdr[curr]);
 			}
 
+			else if (format == F_RAW_OUTPUT) {
+				/* Raw output */
+				(*act[i]->f_raw_print)(act[i], pre, curr);
+			}
+
 			else {
 				/* Other output formats: db, ppc */
 				(*act[i]->f_render)(act[i], (format == F_DB_OUTPUT), pre, curr,
@@ -1109,7 +1114,7 @@ void logic1_display_loop(int ifd, struct file_activity *file_actlst, char *file,
  * Display file contents in selected format (logic #2).
  * Logic #2:	Grouped by activity. Sorted by timestamp. Stop on RESTART
  * 		records.
- * Formats:	ppc, CSV
+ * Formats:	ppc, CSV, raw
  *
  * IN:
  * @ifd		File descriptor of input file.
@@ -1342,6 +1347,9 @@ void logic3_display_loop(int ifd, struct file_activity *file_actlst, __nr_t cpu_
 		}
 	}
 
+	/* Real number of graphs that have been displayed */
+	graph_nr = g_nr;
+
 	/* Print SVG trailer */
 	if (*fmt[f_position]->f_header) {
 		(*fmt[f_position]->f_header)(&graph_nr, F_END, file, file_magic,
@@ -1445,7 +1453,7 @@ int main(int argc, char **argv)
 	while (opt < argc) {
 
 		if (!strcmp(argv[opt], "-I")) {
-			if (argv[++opt] && sar_options) {
+			if (sar_options) {
 				if (parse_sar_I_opt(argv, &opt, act)) {
 					usage(argv[0]);
 				}
@@ -1476,7 +1484,7 @@ int main(int argc, char **argv)
 		}
 
 		else if (!strcmp(argv[opt], "-O")) {
-			/* Parse SVG options */
+			/* Parse output options */
 			if (!argv[++opt] || sar_options) {
 				usage(argv[0]);
 			}
@@ -1493,6 +1501,9 @@ int main(int argc, char **argv)
 				else if (!strcmp(t, K_SHOWIDLE)) {
 					flags |= S_F_SVG_SHOW_IDLE;
 				}
+				else if (!strcmp(t, K_SHOWHINTS)) {
+					flags |= S_F_RAW_SHOW_HINTS;
+				}
 				else {
 					usage(argv[0]);
 				}
@@ -1603,6 +1614,13 @@ int main(int argc, char **argv)
 						format = F_PPC_OUTPUT;
 						break;
 
+					case 'r':
+						if (format) {
+							usage(argv[0]);
+						}
+						format = F_RAW_OUTPUT;
+						break;
+
 					case 'T':
 						flags |= S_F_LOCAL_TIME;
 						break;
