@@ -191,6 +191,34 @@ __printf_funct_t print_json_restart(int *tab, int action, char *cur_date,
 	}
 }
 
+/*
+ ***************************************************************************
+ * Display restart messages (raw format).
+ *
+ * IN:
+ * @tab		Number of tabulations (unused here).
+ * @action	Action expected from current function.
+ * @cur_date	Date string of current restart message.
+ * @cur_time	Time string of current restart message.
+ * @utc		True if @cur_time is expressed in UTC.
+ * @file_hdr	System activity file standard header (unused here).
+ * @cpu_nr	CPU count associated with restart mark.
+ ***************************************************************************
+ */
+__printf_funct_t print_raw_restart(int *tab, int action, char *cur_date,
+				   char *cur_time, int utc, struct file_header *file_hdr,
+				   unsigned int cpu_nr)
+{
+	/* Actions F_BEGIN and F_END ignored */
+	if (action == F_MAIN) {
+		printf("%s", cur_time);
+		if (strlen(cur_date) && utc) {
+			printf(" UTC");
+		}
+		printf("\tLINUX-RESTART\t(%d CPU)\n", cpu_nr > 1 ? cpu_nr - 1 : 1);
+	}
+}
+
 /*
  ***************************************************************************
  * Display comments (database and ppc formats).
@@ -349,6 +377,34 @@ __printf_funct_t print_json_comment(int *tab, int action, char *cur_date,
 	}
 }
 
+/*
+ ***************************************************************************
+ * Display comments (raw format).
+ *
+ * IN:
+ * @tab		Number of tabulations (unused here).
+ * @action	Action expected from current function.
+ * @cur_date	Date string of current restart message.
+ * @cur_time	Time string of current restart message.
+ * @utc		True if @cur_time is expressed in UTC.
+ * @comment	Comment to display.
+ * @file_hdr	System activity file standard header (unused here).
+ ***************************************************************************
+ */
+__printf_funct_t print_raw_comment(int *tab, int action, char *cur_date,
+				   char *cur_time, int utc, char *comment,
+				   struct file_header *file_hdr)
+{
+	/* Actions F_BEGIN and F_END ignored */
+	if (action & F_MAIN) {
+		printf("%s", cur_time);
+		if (strlen(cur_date) && utc) {
+			printf(" UTC");
+		}
+		printf("\tCOM %s\n", comment);
+	}
+}
+
 /*
  ***************************************************************************
  * Display the "statistics" part of the report (XML format).
@@ -529,11 +585,9 @@ __tm_funct_t print_db_timestamp(void *parm, int action, char *cur_date,
  * @action	Action expected from current function.
  * @cur_date	Date string of current comment.
  * @cur_time	Time string of current comment.
- * @utc		True if @cur_time is expressed in UTC.
  * @itv		Interval of time with preceding record.
- *
- * OUT:
- * @tab		Number of tabulations.
+ * @file_hdr	System activity file standard header (unused here).
+ * @flags	Flags for common options.
  ***************************************************************************
  */
 __tm_funct_t print_xml_timestamp(void *parm, int action, char *cur_date,
@@ -563,11 +617,9 @@ __tm_funct_t print_xml_timestamp(void *parm, int action, char *cur_date,
  * @action	Action expected from current function.
  * @cur_date	Date string of current comment.
  * @cur_time	Time string of current comment.
- * @utc		True if @cur_time is expressed in UTC.
  * @itv		Interval of time with preceding record.
- *
- * OUT:
- * @tab		Number of tabulations.
+ * @file_hdr	System activity file standard header (unused here).
+ * @flags	Flags for common options.
  ***************************************************************************
  */
 __tm_funct_t print_json_timestamp(void *parm, int action, char *cur_date,
@@ -593,6 +645,39 @@ __tm_funct_t print_json_timestamp(void *parm, int action, char *cur_date,
 	return NULL;
 }
 
+/*
+ ***************************************************************************
+ * Display the "timestamp" part of the report (raw format).
+ *
+ * IN:
+ * @parm	Pointer on specific parameters (unused here).
+ * @action	Action expected from current function.
+ * @cur_date	Date string of current record.
+ * @cur_time	Time string of current record.
+ * @itv		Interval of time with preceding record (unused here).
+ * @file_hdr	System activity file standard header (unused here).
+ * @flags	Flags for common options.
+ *
+ * RETURNS:
+ * Pointer on the "timestamp" string.
+ ***************************************************************************
+ */
+__tm_funct_t print_raw_timestamp(void *parm, int action, char *cur_date,
+				char *cur_time, unsigned long long itv,
+				struct file_header *file_hdr, unsigned int flags)
+{
+	int utc = !PRINT_LOCAL_TIME(flags) && !PRINT_TRUE_TIME(flags);
+	static char pre[80];
+
+	if (action & F_BEGIN) {
+		snprintf(pre, 80, "%s%s", cur_time, strlen(cur_date) && utc ? " UTC" : "");
+		pre[79] = '\0';
+		return pre;
+	}
+
+	return NULL;
+}
+
 /*
  ***************************************************************************
  * Display the header of the report (XML format).
@@ -608,7 +693,7 @@ __tm_funct_t print_json_timestamp(void *parm, int action, char *cur_date,
  * @id_seq	Activity sequence (unused here).
  *
  * OUT:
- * @tab		Number of tabulations.
+ * @parm	Number of tabulations.
  ***************************************************************************
  */
 __printf_funct_t print_xml_header(void *parm, int action, char *dfile,
@@ -675,7 +760,7 @@ __printf_funct_t print_xml_header(void *parm, int action, char *dfile,
  * @id_seq	Activity sequence (unused here).
  *
  * OUT:
- * @tab		Number of tabulations.
+ * @parm	Number of tabulations.
  ***************************************************************************
  */
 __printf_funct_t print_json_header(void *parm, int action, char *dfile,
@@ -852,6 +937,11 @@ __printf_funct_t print_svg_header(void *parm, int action, char *dfile,
 	}
 
 	if (action & F_END) {
+		if (!(action & F_BEGIN)) {
+			/* Give actual SVG height */
+			printf("<!-- Actual canvas height: %d -->\n",
+			       SVG_H_YSIZE + SVG_T_YSIZE * (*graph_nr));
+		}
 		printf("</svg>\n");
 	}
 }
