@@ -451,12 +451,11 @@ __print_funct_t xml_print_memory_stats(struct activity *a, int curr, int tab,
 				       unsigned long long itv)
 {
 	struct stats_memory
-		*smc = (struct stats_memory *) a->buf[curr],
-		*smp = (struct stats_memory *) a->buf[!curr];
+		*smc = (struct stats_memory *) a->buf[curr];
 
 	xprintf(tab, "<memory per=\"second\" unit=\"kB\">");
 
-	if (DISPLAY_MEM_AMT(a->opt_flags)) {
+	if (DISPLAY_MEMORY(a->opt_flags)) {
 
 		xprintf(++tab, "<memfree>%lu</memfree>",
 			smc->frmkb);
@@ -535,21 +534,6 @@ __print_funct_t xml_print_memory_stats(struct activity *a, int curr, int tab,
 			0.0);
 	}
 
-	if (DISPLAY_MEMORY(a->opt_flags)) {
-
-		xprintf(++tab, "<frmpg>%.2f</frmpg>",
-			S_VALUE((double) KB_TO_PG(smp->frmkb),
-				(double) KB_TO_PG(smc->frmkb), itv));
-
-		xprintf(tab, "<bufpg>%.2f</bufpg>",
-			S_VALUE((double) KB_TO_PG(smp->bufkb),
-				(double) KB_TO_PG(smc->bufkb), itv));
-
-		xprintf(tab--, "<campg>%.2f</campg>",
-			S_VALUE((double) KB_TO_PG(smp->camkb),
-				(double) KB_TO_PG(smc->camkb), itv));
-	}
-
 	xprintf(tab, "</memory>");
 }
 
@@ -677,10 +661,12 @@ __print_funct_t xml_print_disk_stats(struct activity *a, int curr, int tab,
 				     unsigned long long itv)
 {
 	int i, j;
-	struct stats_disk *sdc,	*sdp;
+	struct stats_disk *sdc,	*sdp, sdpzero;
 	struct ext_disk_stats xds;
 	char *dev_name, *persist_dev_name;
 
+	memset(&sdpzero, 0, STATS_DISK_SIZE);
+
 	xprintf(tab++, "<disk per=\"second\">");
 
 	for (i = 0; i < a->nr; i++) {
@@ -691,7 +677,13 @@ __print_funct_t xml_print_disk_stats(struct activity *a, int curr, int tab,
 			continue;
 
 		j = check_disk_reg(a, curr, !curr, i);
-		sdp = (struct stats_disk *) ((char *) a->buf[!curr] + j * a->msize);
+		if (j < 0) {
+			/* This is a newly registered interface. Previous stats are zero */
+			sdp = &sdpzero;
+		}
+		else {
+			sdp = (struct stats_disk *) ((char *) a->buf[!curr] + j * a->msize);
+		}
 
 		/* Compute extended statistics values */
 		compute_ext_disk_stats(sdc, sdp, itv, &xds);
@@ -757,12 +749,14 @@ __print_funct_t xml_print_net_dev_stats(struct activity *a, int curr, int tab,
 					unsigned long long itv)
 {
 	int i, j;
-	struct stats_net_dev *sndc, *sndp;
+	struct stats_net_dev *sndc, *sndp, sndzero;
 	double rxkb, txkb, ifutil;
 
 	if (!IS_SELECTED(a->options) || (a->nr <= 0))
 		goto close_xml_markup;
 
+	memset(&sndzero, 0, STATS_NET_DEV_SIZE);
+
 	xml_markup_network(tab, OPEN_XML_MARKUP);
 	tab++;
 
@@ -771,10 +765,16 @@ __print_funct_t xml_print_net_dev_stats(struct activity *a, int curr, int tab,
 		sndc = (struct stats_net_dev *) ((char *) a->buf[curr] + i * a->msize);
 
 		if (!strcmp(sndc->interface, ""))
-			continue;
+			break;
 
 		j = check_net_dev_reg(a, curr, !curr, i);
-		sndp = (struct stats_net_dev *) ((char *) a->buf[!curr] + j * a->msize);
+		if (j < 0) {
+			/* This is a newly registered interface. Previous stats are zero */
+			sndp = &sndzero;
+		}
+		else {
+			sndp = (struct stats_net_dev *) ((char *) a->buf[!curr] + j * a->msize);
+		}
 
 		rxkb = S_VALUE(sndp->rx_bytes, sndc->rx_bytes, itv);
 		txkb = S_VALUE(sndp->tx_bytes, sndc->tx_bytes, itv);
@@ -822,11 +822,13 @@ __print_funct_t xml_print_net_edev_stats(struct activity *a, int curr, int tab,
 					 unsigned long long itv)
 {
 	int i, j;
-	struct stats_net_edev *snedc, *snedp;
+	struct stats_net_edev *snedc, *snedp, snedzero;
 
 	if (!IS_SELECTED(a->options) || (a->nr <= 0))
 		goto close_xml_markup;
 
+	memset(&snedzero, 0, STATS_NET_EDEV_SIZE);
+
 	xml_markup_network(tab, OPEN_XML_MARKUP);
 	tab++;
 
@@ -835,10 +837,16 @@ __print_funct_t xml_print_net_edev_stats(struct activity *a, int curr, int tab,
 		snedc = (struct stats_net_edev *) ((char *) a->buf[curr] + i * a->msize);
 
 		if (!strcmp(snedc->interface, ""))
-			continue;
+			break;
 
 		j = check_net_edev_reg(a, curr, !curr, i);
-		snedp = (struct stats_net_edev *) ((char *) a->buf[!curr] + j * a->msize);
+		if (j < 0) {
+			/* This is a newly registered interface. Previous stats are zero */
+			snedp = &snedzero;
+		}
+		else {
+			snedp = (struct stats_net_edev *) ((char *) a->buf[!curr] + j * a->msize);
+		}
 
 		xprintf(tab, "<net-edev iface=\"%s\" "
 			"rxerr=\"%.2f\" "
